@@ -63,7 +63,7 @@ class MessageCatalogue(object):
         if domain is None:
             return {k: dict(v) for k, v in self.messages.items()}
 
-        return dict(self.messages.get(domain, {})
+        return dict(self.messages.get(domain, {}))
 
     def set(self, id, translation, domain='messages'):
         """
